@@ -1,10 +1,11 @@
-#include <QtMaemo5/QMaemo5KineticScroller>
-
 #include "mainwindow.h"
 #include "settingsdlg.h"
+#include "helpdialog.h"
 #include "Settings.h"
 #include "SiBApplication.h"
 #include "videofile.h"
+#include "filelist.h"
+#include <QAbstractKineticScroller>
 
 MainWindow::MainWindow()
 {
@@ -30,6 +31,15 @@ MainWindow::MainWindow()
     helpButton->setFont( buttonFont );
     helpButton->setGeometry( buttonLeftOffset, 320, buttonWidth, buttonHeight );
     m_fileList = new QTableWidget( 0, 3, this );
+
+    QAbstractKineticScroller* scroller = m_fileList->property("kineticScroller").value<QAbstractKineticScroller *>();
+    if ( scroller ) {
+        //scroller->setMode( QAbstractKineticScroller::PushMode );
+        //printf( "Mode:%d, inertia: %f, fvf:%f min vel:%f max vel:%f\n", scroller->mode(), scroller->dragInertia(), scroller->fastVelocityFactor(), scroller->minimumVelocity(), scroller->maximumVelocity() );
+        scroller->setEnabled( false );
+        //scroller->setMaximumVelocity( 100.0 );
+    }
+
     m_fileList->setGeometry( 190, 5, 605, 415 );
 
     QStringList labels;
@@ -42,11 +52,8 @@ MainWindow::MainWindow()
     m_fileList->horizontalHeader()->setResizeMode( 2, QHeaderView::ResizeToContents );
     m_fileList->verticalHeader()->hide();
     m_fileList->setShowGrid(false);
-    //m_fileList->setAlternatingRowColors( true );
     m_fileList->setVerticalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
 
-    new QMaemo5KineticScroller( m_fileList );
-
     connect( m_playbutton, SIGNAL( clicked() ),
              this, SLOT( playButtonPressed() ) );
 
@@ -64,6 +71,12 @@ MainWindow::MainWindow()
 
     connect( m_fileList, SIGNAL( cellClicked( int, int ) ),
         this, SLOT( cellClicked( int, int ) ) );
+
+    connect( m_fileList->horizontalHeader(), SIGNAL( sectionClicked(int) ),
+             this, SLOT( resort( int ) ) );
+
+    m_sortByColumn = 0;
+    m_sortOrder = Qt::AscendingOrder;
 }
 
 MainWindow::~MainWindow()
@@ -81,7 +94,7 @@ void MainWindow::keyPressEvent ( QKeyEvent* event )
 
 void MainWindow::updateFileList( const QList<VideoFile*>& files )
 {
-    m_fileList->setRowCount(0);
+    m_fileList->setRowCount( 0 );
 
     for ( int i = 0; i < files.count(); i++ )
     {
@@ -135,17 +148,8 @@ void MainWindow::settingsButtonPressed()
 
 void MainWindow::helpButtonPressed()
 {
-	QMessageBox::information( this, tr( "Default MPlayer Keyboard Shortcuts"), tr( "\
- left/right\tseek backward/forward 10 seconds \n\
- down/up\tseek backward/forward  1 minute \n\
- p or SPACE\tpause movie (press any key to continue) \n\
- q\t\tstop playing\n\
- f\t\ttoggle fullscreen\n\
- + or -\t\tadjust audio delay by +/- 0.1 second\n\
- o\t\tcycle OSD mode:  none / seekbar / seekbar + timer\n\
- x or z\t\tadjust subtitle delay by +/- 0.1 second\n\
- r or t\t\tadjust subtitle position up/down\n\
-" ) );
+    HelpDialog help;
+    help.exec();
 }
 
 void MainWindow::fileSelected( int row, int /*column*/ )
@@ -170,6 +174,37 @@ void MainWindow::cellClicked( int row, int /*column*/ )
     }
 }
 
+void MainWindow::resort( int column )
+{
+    if ( m_sortByColumn != column ) {
+        m_sortByColumn = column;
+        m_sortOrder = Qt::AscendingOrder;
+    } else {
+        if ( m_sortOrder == Qt::AscendingOrder ) {
+            m_sortOrder = Qt::DescendingOrder;
+        } else {
+            m_sortOrder = Qt::AscendingOrder;
+        }
+    }
+
+    FileList::SortCriteria criteria;
+    switch( column ) {
+        case 0: // sort by name
+            criteria = FileList::ESortByName;
+            break;
+        case 1: // sort by file size
+            criteria = FileList::ESortBySize;
+            break;
+        case 2: // sort by resume pos
+            criteria = FileList::ESortByResumePos;
+            break;
+        default: // won't happen
+            break;
+    }
+
+    SiBApplication::instance()->sortFileList( criteria, m_sortOrder );
+}
+
 void MainWindow::playerStart()
 {
 	m_playbutton->setText( tr( "Stop" ) );
