@@ -33,6 +33,7 @@ class MainWindow : public QWidget {
         void helpButtonPressed();
         void fileSelected( int row, int column );
         void cellClicked( int row, int column );
+        void resort( int column );
         void playerStart();
         void playerStop();
 
@@ -43,6 +44,8 @@ class MainWindow : public QWidget {
         QTableWidget* m_fileList;
         QPushButton* m_playbutton;
         QPushButton* m_resumebutton;
+        int m_sortByColumn;
+        Qt::SortOrder m_sortOrder;
 };
 
 #endif // MAINWINDOW_H
